@@ -474,16 +474,20 @@ from data.models.models import HardwareStats, DataTransformer, DataTransformerCo
     HardwareStatsDataTransformer
 
 DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, fk_name='data_transformer_parent',
-                                                     extra=1,exclude =['updated_at','created_at'])
+                                                     extra=1,exclude =['updated_at','created_at'],formset=DataTransformerForm)
 DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,exclude =['updated_at','created_at'])
 HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,exclude =['updated_at','created_at'])
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,exclude =['updated_at','created_at'])
 
 
 class DataTransformerForm(BaseInlineFormSet,BaseModelFormSet):
+
     def __init__(self, *args, **kwargs):
         super(DataTransformerForm, self).__init__(*args, **kwargs)
-
+        self.DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                             fk_name='data_transformer_parent',
+                                                             extra=1, exclude=['updated_at', 'created_at'],
+                                                             formset=self.__class__)
         for name in self.fields.keys():
             self.fields[name].widget.attrs.update({
                 'class': 'form-control',
@@ -492,7 +496,7 @@ class DataTransformerForm(BaseInlineFormSet,BaseModelFormSet):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
-        form.nested_data_transformer_form = DataTransformerForm(
+        form.nested_data_transformer_form = self.DataTransformerInlineFormset(
             instance=form.instance,
             data=form.data if form.is_bound else None,
             files=form.files if form.is_bound else None,
